@@ -11,7 +11,7 @@ const char* const SPVM_DESCRIPTOR_C_ID_NAMES[] = {
   "public",
   "private",
   "pointer",
-  "values"
+  "value_t"
 };
 
 SPVM_DESCRIPTOR* SPVM_DESCRIPTOR_new(SPVM_COMPILER* compiler) {
