@@ -6,7 +6,7 @@
 struct SPVM_my {
   SPVM_OP* op_type;
   SPVM_OP* op_name;
-  int32_t index;
+  int32_t var_id;
   SPVM_OP* op_term_type_inference;
   _Bool try_type_inference;
   _Bool is_arg;
