@@ -264,12 +264,7 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "CALL_SUB",
   "CALL_INTERFACE_METHOD",
   "RETURN_VOID",
-  "RETURN_BYTE",
-  "RETURN_SHORT",
-  "RETURN_INT",
-  "RETURN_LONG",
-  "RETURN_FLOAT",
-  "RETURN_DOUBLE",
+  "RETURN",
   "RETURN_OBJECT",
   "RETURN_UNDEF",
   "CROAK",
@@ -317,16 +312,11 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "MOVE_DOUBLE",
   "MOVE_OBJECT",
   "MOVE_UNDEF",
+  "MOVE_VALUES",
   "ENTER_SCOPE",
   "PUSH_MORTAL",
   "LEAVE_SCOPE",
-  "PUSH_ARG_BYTE",
-  "PUSH_ARG_SHORT",
-  "PUSH_ARG_INT",
-  "PUSH_ARG_LONG",
-  "PUSH_ARG_FLOAT",
-  "PUSH_ARG_DOUBLE",
-  "PUSH_ARG_OBJECT",
+  "PUSH_ARG",
   "PUSH_ARG_UNDEF",
   "CHECK_CAST",
   "STRING_EQ",
