@@ -264,12 +264,7 @@ enum {
   SPVM_OPCODE_C_ID_CALL_SUB,
   SPVM_OPCODE_C_ID_CALL_INTERFACE_METHOD,
   SPVM_OPCODE_C_ID_RETURN_VOID,
-  SPVM_OPCODE_C_ID_RETURN_BYTE,
-  SPVM_OPCODE_C_ID_RETURN_SHORT,
-  SPVM_OPCODE_C_ID_RETURN_INT,
-  SPVM_OPCODE_C_ID_RETURN_LONG,
-  SPVM_OPCODE_C_ID_RETURN_FLOAT,
-  SPVM_OPCODE_C_ID_RETURN_DOUBLE,
+  SPVM_OPCODE_C_ID_RETURN,
   SPVM_OPCODE_C_ID_RETURN_OBJECT,
   SPVM_OPCODE_C_ID_RETURN_UNDEF,
   SPVM_OPCODE_C_ID_CROAK,
@@ -317,16 +312,11 @@ enum {
   SPVM_OPCODE_C_ID_MOVE_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_OBJECT,
   SPVM_OPCODE_C_ID_MOVE_UNDEF,
+  SPVM_OPCODE_C_ID_MOVE_VALUES,
   SPVM_OPCODE_C_ID_ENTER_SCOPE,
   SPVM_OPCODE_C_ID_PUSH_MORTAL,
   SPVM_OPCODE_C_ID_LEAVE_SCOPE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_BYTE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_SHORT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_INT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_LONG,
-  SPVM_OPCODE_C_ID_PUSH_ARG_FLOAT,
-  SPVM_OPCODE_C_ID_PUSH_ARG_DOUBLE,
-  SPVM_OPCODE_C_ID_PUSH_ARG_OBJECT,
+  SPVM_OPCODE_C_ID_PUSH_ARG,
   SPVM_OPCODE_C_ID_PUSH_ARG_UNDEF,
   SPVM_OPCODE_C_ID_CHECK_CAST,
   SPVM_OPCODE_C_ID_STRING_EQ,
