@@ -20,10 +20,12 @@ void* SPVM_RUNTIME_ALLOCATOR_alloc(SPVM_RUNTIME* runtime, int32_t byte_size) {
 void SPVM_RUNTIME_ALLOCATOR_free(SPVM_RUNTIME* runtime, void* block) {
   (void)runtime;
   
-  free(block);
-  runtime->objects_count--;
-  
+  if (block) {
+    free(block);
+    runtime->objects_count--;
+    
 #ifdef SPVM_DEBUG_OBJECT_COUNT
-  fprintf(stderr, "[DEC_OBJ_CNT] %d\n", runtime->objects_count);
+    fprintf(stderr, "[DEC_OBJ_CNT] %d\n", runtime->objects_count);
 #endif
+  }
 }
